@@ -1,9 +1,8 @@
 mdes.bcra4f3 <- function(power=.80, alpha=.05, two.tailed=TRUE,
                         rho2, rho3, p=.50, r21=0, r22=0, r23=0, g3=0,
-                        n, J, K, L, ...){
+                        n, J, K, L){
 
-  user.parms <- as.list(match.call(expand.dots = TRUE))
-  .depdef(user.parms)
+  user.parms <- as.list(match.call())
   .error.handler(user.parms)
 
   df <- L * (K - 2) - g3
@@ -30,10 +29,9 @@ mdes.bcra4f3 <- function(power=.80, alpha=.05, two.tailed=TRUE,
 
 power.bcra4f3 <- function(es=.25, alpha=.05, two.tailed=TRUE,
                          rho2, rho3, p=.50, r21=0, r22=0, r23=0, g3=0,
-                         n, J, K, L, ...){
+                         n, J, K, L){
 
-  user.parms <- as.list(match.call(expand.dots = TRUE))
-  .depdef(user.parms)
+  user.parms <- as.list(match.call())
   .error.handler(user.parms)
 
   df <- L * (K - 2) - g3
@@ -59,10 +57,9 @@ power.bcra4f3 <- function(es=.25, alpha=.05, two.tailed=TRUE,
 
 mrss.bcra4f3 <- function(es=.25, power=.80, alpha=.05, two.tailed=TRUE,
                          n, J, K, L0=10, tol=.10,
-                         rho2, rho3, p=.50, g3=0, r21=0, r22=0, r23=0, ...){
+                         rho2, rho3, p=.50, g3=0, r21=0, r22=0, r23=0){
 
-  user.parms <- as.list(match.call(expand.dots = TRUE))
-  .depdef(user.parms)
+  user.parms <- as.list(match.call())
   .error.handler(user.parms)
 
   i <- 0
