@@ -1,9 +1,8 @@
 mdes.cra4r4 <- function(power=.80, alpha=.05, two.tailed=TRUE,
                         rho2, rho3, rho4, p=.50, r21=0, r22=0, r23=0, r24=0, g4=0,
-                        n, J, K, L, ...){
+                        n, J, K, L){
 
-  user.parms <- as.list(match.call(expand.dots = TRUE))
-  .depdef(user.parms)
+  user.parms <- as.list(match.call())
   .error.handler(user.parms)
 
   df <- L - g4 - 2
@@ -31,10 +30,9 @@ mdes.cra4r4 <- function(power=.80, alpha=.05, two.tailed=TRUE,
 
 power.cra4r4 <- function(es=.25, alpha=.05, two.tailed=TRUE,
                          rho2, rho3, rho4, p=.50, r21=0, r22=0, r23=0, r24=0, g4=0,
-                         n, J, K, L, ...){
+                         n, J, K, L){
 
-  user.parms <- as.list(match.call(expand.dots = TRUE))
-  .depdef(user.parms)
+  user.parms <- as.list(match.call())
   .error.handler(user.parms)
 
   df <- L - g4 - 2
@@ -61,10 +59,9 @@ power.cra4r4 <- function(es=.25, alpha=.05, two.tailed=TRUE,
 
 mrss.cra4r4 <- function(es=.25, power=.80, alpha=.05, two.tailed=TRUE,
                         n, J, K, L0=10, tol=.10,
-                        rho2, rho3, rho4, p=.50, r21=0, r22=0, r23=0, r24=0, g4=0, ...){
+                        rho2, rho3, rho4, p=.50, r21=0, r22=0, r23=0, r24=0, g4=0){
 
-  user.parms <- as.list(match.call(expand.dots = TRUE))
-  .depdef(user.parms)
+  user.parms <- as.list(match.call())
   .error.handler(user.parms)
 
   i <- 0
